diff
stringlengths 65
26.7k
| message
stringlengths 7
9.92k
|
|---|---|
diff --git a/generators/generator-base.js b/generators/generator-base.js
index <HASH>..<HASH> 100644
--- a/generators/generator-base.js
+++ b/generators/generator-base.js
@@ -2548,6 +2548,7 @@ templates: ${JSON.stringify(existingTemplates, null, 2)}`;
to: blockToCallback,
condition: blockConditionCallback,
transform: blockTransform = [],
+ renameTo: blockRenameTo,
} = block;
assert(typeof block === 'object', `Block must be an object for ${blockSpecPath}`);
assert(Array.isArray(block.templates), `Block templates must be an array for ${blockSpecPath}`);
@@ -2570,7 +2571,12 @@ templates: ${JSON.stringify(existingTemplates, null, 2)}`;
}
if (typeof fileSpec === 'string') {
const sourceFile = path.join(blockPath, fileSpec);
- const destinationFile = this.destinationPath(blockTo, fileSpec);
+ let destinationFile;
+ if (blockRenameTo) {
+ destinationFile = this.destinationPath(blockRenameTo.call(this, context, fileSpec, this));
+ } else {
+ destinationFile = this.destinationPath(blockTo, fileSpec);
+ }
return { sourceFile, destinationFile, noEjs, transform: derivedTransform };
}
|
add renameTo support to blocks
|
diff --git a/asv/commands/run.py b/asv/commands/run.py
index <HASH>..<HASH> 100644
--- a/asv/commands/run.py
+++ b/asv/commands/run.py
@@ -26,7 +26,6 @@ class Run(object):
"run", help="Run a benchmark suite",
description="Run a benchmark suite.")
- # TODO: Range of branches
parser.add_argument(
"--range", "-r", default="master^!",
help="""Range of commits to benchmark. This is passed as
@@ -40,8 +39,8 @@ class Run(object):
reasonable number.""")
parser.add_argument(
"--bench", "-b", type=str, nargs="*",
- help="""Regular expression for benchmark to run. When
- none are provided, all benchmarks are run.""")
+ help="""Regular expression(s) for benchmark to run. When
+ not provided, all benchmarks are run.""")
parser.set_defaults(func=cls.run_from_args)
@@ -85,8 +84,8 @@ class Run(object):
steps = len(commit_hashes) * len(benchmarks) * len(environments)
console.message(
- "Running {0} total benchmarks ({1} commits * {2} benchmarks * {3} environments)".format(
- steps, len(commit_hashes), len(benchmarks), len(environments)), "green")
+ "Running {0} total benchmarks ({1} commits * {2} environments * {3} benchmarks)".format(
+ steps, len(commit_hashes), len(environments), len(benchmarks)), "green")
console.set_nitems(steps)
for env in environments:
|
Improve "asv run"'s output
|
diff --git a/manifest.php b/manifest.php
index <HASH>..<HASH> 100644
--- a/manifest.php
+++ b/manifest.php
@@ -58,7 +58,7 @@ return array(
'taoQtiTest' => '>=34.2.0',
'taoOutcomeUi' => '>=7.0.0',
'taoEventLog' => '>=2.0.0',
- 'generis' => '>=11.2.0',
+ 'generis' => '>=12.5.0',
),
'managementRole' => 'http://www.tao.lu/Ontologies/TAOProctor.rdf#TestCenterManager',
'acl' => array(
|
TTD-<I> Added\changed 'generis' version to '>=<I>' in `requires` secition
|
diff --git a/tests/TestCase/Network/Email/SmtpTransportTest.php b/tests/TestCase/Network/Email/SmtpTransportTest.php
index <HASH>..<HASH> 100644
--- a/tests/TestCase/Network/Email/SmtpTransportTest.php
+++ b/tests/TestCase/Network/Email/SmtpTransportTest.php
@@ -511,7 +511,7 @@ class SmtpTransportTest extends TestCase {
* @return void
*/
public function testExplicitDisconnectNotConnected() {
- $callback = function($arg) {
+ $callback = function($arg) {
$this->assertNotEquals("QUIT\r\n", $arg);
};
$this->socket->expects($this->any())->method('write')->will($this->returnCallback($callback));
@@ -532,7 +532,7 @@ class SmtpTransportTest extends TestCase {
$email->to('cake@cakephp.org', 'CakePHP');
$email->expects($this->exactly(2))->method('message')->will($this->returnValue(array('First Line')));
- $callback = function($arg) {
+ $callback = function($arg) {
$this->assertNotEquals("QUIT\r\n", $arg);
};
$this->socket->expects($this->any())->method('write')->will($this->returnCallback($callback));
|
Fix CS in SmtpTransportTest
|
diff --git a/addon/metrics-adapters/keen.js b/addon/metrics-adapters/keen.js
index <HASH>..<HASH> 100644
--- a/addon/metrics-adapters/keen.js
+++ b/addon/metrics-adapters/keen.js
@@ -208,6 +208,7 @@ export default BaseAdapter.extend({
name: 'keen:ip_to_geo',
input: {
ip: 'tech.ip',
+ remove_ip_property: true,
},
output: 'geo',
});
|
Anonymize the client IP address for keen adapter (#<I>)
|
diff --git a/src/UserPage.php b/src/UserPage.php
index <HASH>..<HASH> 100644
--- a/src/UserPage.php
+++ b/src/UserPage.php
@@ -67,7 +67,7 @@ class UserPage extends Page
$aData = [
'cb_pagetype' => filter_var($this->cb_pagetype, FILTER_SANITIZE_STRING, FILTER_FLAG_STRIP_LOW),
'cb_group' => filter_var($this->cb_group, FILTER_SANITIZE_STRING, FILTER_FLAG_STRIP_LOW),
- 'cb_pageconfig' => $this->purifier->purify($this->cb_pageconfig),
+ 'cb_pageconfig' => $this->cb_pageconfig,
'cb_subnav' => filter_var($this->cb_subnav, FILTER_SANITIZE_STRING, FILTER_FLAG_STRIP_LOW),
'cb_key' => $this->cb_key,
];
|
removed inapproptiate use of purifier
|
diff --git a/couch/tests/test_unit.py b/couch/tests/test_unit.py
index <HASH>..<HASH> 100644
--- a/couch/tests/test_unit.py
+++ b/couch/tests/test_unit.py
@@ -38,4 +38,4 @@ def test_config(test_case, extra_config, expected_http_kwargs):
)
http_wargs.update(expected_http_kwargs)
- r.get.assert_called_with('http://localhost:5984/_all_dbs/', **http_wargs)
+ r.get.assert_called_with('http://{}:5984/_all_dbs/'.format(common.HOST), **http_wargs)
|
Fix tests running on non localhost (#<I>)
Common is refering to the docker host, we need to use it in the results
as well.
|
diff --git a/src/main/java/org/altbeacon/beacon/service/scanner/CycledLeScanner.java b/src/main/java/org/altbeacon/beacon/service/scanner/CycledLeScanner.java
index <HASH>..<HASH> 100644
--- a/src/main/java/org/altbeacon/beacon/service/scanner/CycledLeScanner.java
+++ b/src/main/java/org/altbeacon/beacon/service/scanner/CycledLeScanner.java
@@ -9,7 +9,6 @@ import android.bluetooth.BluetoothManager;
import android.content.Context;
import android.content.Intent;
import android.os.Handler;
-import android.util.Log;
import org.altbeacon.beacon.BeaconManager;
import org.altbeacon.beacon.logging.LogManager;
@@ -319,7 +318,7 @@ public abstract class CycledLeScanner {
// devices.
long milliseconds = Long.MAX_VALUE; // 2.9 million years from now
AlarmManager alarmManager = (AlarmManager) mContext.getSystemService(Context.ALARM_SERVICE);
- alarmManager.set(AlarmManager.RTC_WAKEUP, System.currentTimeMillis() + milliseconds, getWakeUpOperation());
+ alarmManager.set(AlarmManager.RTC_WAKEUP, milliseconds, getWakeUpOperation());
LogManager.d(TAG, "Set a wakeup alarm to go off in %s ms: %s", milliseconds, getWakeUpOperation());
}
|
-fixing canceling alarm. It reschedule it for max time in the future. It was done with overflow resulting in an instant alarm deploy due to the time in the past.
|
diff --git a/acceptancetests/jujupy/client.py b/acceptancetests/jujupy/client.py
index <HASH>..<HASH> 100644
--- a/acceptancetests/jujupy/client.py
+++ b/acceptancetests/jujupy/client.py
@@ -1605,8 +1605,7 @@ class ModelClient:
Note: A model is often called an enviroment (Juju 1 legacy).
- This class represents the latest Juju version. Subclasses are used to
- support older versions (see get_client_class).
+ This class represents the latest Juju version.
"""
# The environments.yaml options that are replaced by bootstrap options.
diff --git a/acceptancetests/jujupy/tests/test_client.py b/acceptancetests/jujupy/tests/test_client.py
index <HASH>..<HASH> 100644
--- a/acceptancetests/jujupy/tests/test_client.py
+++ b/acceptancetests/jujupy/tests/test_client.py
@@ -291,7 +291,7 @@ class TestJuju2Backend(TestCase):
soft_deadline=None)
with patch('subprocess.Popen') as mock_popen:
mock_popen.return_value.communicate.return_value = (
- '{"current-model": "model"}', '')
+ b'{"current-model": "model"}', b'')
mock_popen.return_value.returncode = 0
result = backend.get_active_model('/foo/bar')
self.assertEqual(('model'), result)
|
Clarify testing with py3
|
diff --git a/mmcv/ops/cc_attention.py b/mmcv/ops/cc_attention.py
index <HASH>..<HASH> 100644
--- a/mmcv/ops/cc_attention.py
+++ b/mmcv/ops/cc_attention.py
@@ -3,7 +3,7 @@ import torch.nn as nn
import torch.nn.functional as F
from torch.autograd.function import once_differentiable
-from mmcv.cnn import Scale
+from mmcv.cnn import PLUGIN_LAYERS, Scale
from ..utils import ext_loader
ext_module = ext_loader.load_ext(
@@ -66,6 +66,7 @@ ca_weight = CAWeightFunction.apply
ca_map = CAMapFunction.apply
+@PLUGIN_LAYERS.register_module()
class CrissCrossAttention(nn.Module):
"""Criss-Cross Attention Module."""
|
[Feature]: Register CrissCrossAttention into plugin layers (#<I>)
|
diff --git a/sos/plugins/openvswitch.py b/sos/plugins/openvswitch.py
index <HASH>..<HASH> 100644
--- a/sos/plugins/openvswitch.py
+++ b/sos/plugins/openvswitch.py
@@ -49,7 +49,9 @@ class OpenVSwitch(Plugin):
# List devices and their drivers
"dpdk_nic_bind --status",
# Capture a list of all bond devices
- "ovs-appctl bond/list"
+ "ovs-appctl bond/list",
+ # Capture more details from bond devices
+ "ovs-appctl bond/show"
])
# Gather additional output for each OVS bridge on the host.
|
[openvswitch] capture additional info from bonds
Provide more details for each bond device.
|
diff --git a/lib/ronin/database/database.rb b/lib/ronin/database/database.rb
index <HASH>..<HASH> 100644
--- a/lib/ronin/database/database.rb
+++ b/lib/ronin/database/database.rb
@@ -105,6 +105,15 @@ module Ronin
end
#
+ # Returns +true+ if the Database is setup, returns +false+ otherwise.
+ #
+ def Database.setup?
+ repository = DataMapper.repository(Model::REPOSITORY_NAME)
+
+ return repository.class.adapters.has_key?(repository.name)
+ end
+
+ #
# Call the given _block_ then update the Database.
#
def Database.update!(&block)
|
Added Database.setup?.
|
diff --git a/lib/platform/github/gh-got-wrapper.js b/lib/platform/github/gh-got-wrapper.js
index <HASH>..<HASH> 100644
--- a/lib/platform/github/gh-got-wrapper.js
+++ b/lib/platform/github/gh-got-wrapper.js
@@ -11,7 +11,7 @@ function sleep(ms) {
async function get(path, opts, retries = 5) {
const method = opts && opts.method ? opts.method : 'get';
- logger.debug({ retries }, `${method.toUpperCase()} ${path}`);
+ logger.debug(`${method.toUpperCase()} ${path} [retries=${retries}]`);
if (method === 'get' && cache[path]) {
logger.debug({ path }, 'Returning cached result');
return cache[path];
|
fix: better retries log in github wrapper
|
diff --git a/style.js b/style.js
index <HASH>..<HASH> 100644
--- a/style.js
+++ b/style.js
@@ -54,12 +54,12 @@ export function same(a, b) {
export function contains(set, style) {
for (let i = 0; i < set.length; i++)
- if (same(set[i], style)) return set[i]
+ if (same(set[i], style)) return true
return false
}
export function containsType(set, type) {
for (let i = 0; i < set.length; i++)
- if (set[i].type == type) return true
+ if (set[i].type == type) return set[i]
return false
}
|
Add inverses of steps, test them
|
diff --git a/bin/sass-shake.js b/bin/sass-shake.js
index <HASH>..<HASH> 100755
--- a/bin/sass-shake.js
+++ b/bin/sass-shake.js
@@ -11,7 +11,7 @@ program
.option('-f, --entryPoints <entryPoints>', 'Sass entry point files', list)
.option('-e, --exclude <exclusions>', 'An array of regexp pattern strings that are matched against files to exclude them from the unused files list', list, [])
.option('-s, --silent', 'Suppress logs')
- .option('-d, --deleteFiles', 'Delete the unused files')
+ .option('-d, --delete', 'Delete the unused files')
.option('-t, --hideTable', 'Hide the unused files table')
.parse(process.argv);
|
Fixes CLI delete option
The option parameter was being ignored as it was called delete instead of the CLI deleteFiles and it wouldn't work.
|
diff --git a/src/AdamWathan/Form/FormBuilder.php b/src/AdamWathan/Form/FormBuilder.php
index <HASH>..<HASH> 100644
--- a/src/AdamWathan/Form/FormBuilder.php
+++ b/src/AdamWathan/Form/FormBuilder.php
@@ -132,8 +132,6 @@ class FormBuilder
public function radio($name, $value = null)
{
- $value = is_null($value) ? $name : $value;
-
$radio = new RadioButton($name, $value);
$oldValue = $this->getValueFor($name);
|
Removing duplicate logic (already in RadioButton's constructor).
|
diff --git a/classes/Backtrace.php b/classes/Backtrace.php
index <HASH>..<HASH> 100644
--- a/classes/Backtrace.php
+++ b/classes/Backtrace.php
@@ -54,8 +54,8 @@ class QM_Backtrace {
protected $calling_line = 0;
protected $calling_file = '';
- public function __construct( array $args = array() ) {
- $this->trace = debug_backtrace( false );
+ public function __construct( array $args = array(), array $trace = null ) {
+ $this->trace = $trace ? $trace : debug_backtrace( false );
$args = array_merge( array(
'ignore_current_filter' => true,
|
Support passing backtrace to QM_Backtrace
|
diff --git a/test/commands/package-test.js b/test/commands/package-test.js
index <HASH>..<HASH> 100644
--- a/test/commands/package-test.js
+++ b/test/commands/package-test.js
@@ -32,7 +32,8 @@ vows.describe('jitsu/commands/package').addBatch({
},
function setup() {
var tmproot = jitsu.config.get('tmproot'),
- targetPackage = path.join(tmproot, 'tester-example-app-0.0.0-1.tgz');
+ targetPackage = path.join(tmproot, 'tester-example-app-0.0.0-1.tgz'),
+ packageFile = path.join(__dirname, '..', 'fixtures', 'example-app', 'package.json');;
jitsu.argv.noanalyze = true;
jitsu.prompt.override['invite code'] = 'f4387f4';
@@ -41,6 +42,15 @@ vows.describe('jitsu/commands/package').addBatch({
// Change directory to the sample app
//
process.chdir(path.join(__dirname, '..', 'fixtures', 'example-app'));
+
+ var pkg = {
+ name: 'example-app',
+ subdomain: 'example-app',
+ scripts: { start: 'server.js' },
+ version: '0.0.0-1'
+ };
+
+ fs.writeFileSync(packageFile, JSON.stringify(pkg, true, 2))
//
// Attempt to remove any existing tarballs
|
[test fix] Explicitly reset the package.json before running the package test
|
diff --git a/lib/grit_adapter.rb b/lib/grit_adapter.rb
index <HASH>..<HASH> 100644
--- a/lib/grit_adapter.rb
+++ b/lib/grit_adapter.rb
@@ -77,6 +77,12 @@ module DTK
tree_or_blob && tree_or_blob.kind_of?(::Grit::Blob) && tree_or_blob.data
end
+ def file_content_and_size(path)
+ tree_or_blob = tree/path
+ return nil unless tree_or_blob
+ { :data => tree_or_blob.data, :size => tree_or_blob.size }
+ end
+
def push(remote_branch_ref=nil)
remote_repo,remote_branch = parse_remote_branch_ref(remote_branch_ref)
Git_command__push_mutex.synchronize do
|
Added support to retrive file size needed for file upload
|
diff --git a/bundler.d/development.rb b/bundler.d/development.rb
index <HASH>..<HASH> 100644
--- a/bundler.d/development.rb
+++ b/bundler.d/development.rb
@@ -25,5 +25,5 @@ group :development do
gem 'minitest-rails'
gem 'factory_girl_rails', "~> 1.4.0"
- gem 'rubocop', "~> 0.13.0"
+ gem 'rubocop', "0.13.0"
end
|
Rubocop: New version breaks everything!
|
diff --git a/geopy/adapters.py b/geopy/adapters.py
index <HASH>..<HASH> 100644
--- a/geopy/adapters.py
+++ b/geopy/adapters.py
@@ -77,10 +77,9 @@ class AdapterHTTPError(IOError):
:param int status_code: HTTP status code.
:param dict headers: HTTP response readers. A mapping object
with lowercased or case-insensitive keys.
- :param str text: HTTP body text.
- .. versionchanged:: 2.2
- Added ``headers``.
+ .. versionadded:: 2.2
+ :param str text: HTTP body text.
"""
self.status_code = status_code
self.headers = headers
|
docs adapters: versionchanged -> versionadded (#<I>)
|
diff --git a/app/Blueprint/Webserver/WebserverBlueprint.php b/app/Blueprint/Webserver/WebserverBlueprint.php
index <HASH>..<HASH> 100644
--- a/app/Blueprint/Webserver/WebserverBlueprint.php
+++ b/app/Blueprint/Webserver/WebserverBlueprint.php
@@ -266,9 +266,6 @@ class WebserverBlueprint implements Blueprint, TakesDockerAccount {
protected function makeDockerfile(Configuration $config):Dockerfile {
$dockerfile = new Dockerfile();
- $dockerfile->setUser( self::WWW_DATA_USER_ID );
- $dockerfile->setGroup( self::WWW_DATA_GROUP_ID );
-
$dockerfile->setFrom($config->get('docker.base-image'));
$dockerfile->addVolume('/var/www/app');
@@ -278,6 +275,8 @@ class WebserverBlueprint implements Blueprint, TakesDockerAccount {
$dockerfile->copy('.'.$copySuffix, '/var/www/app'.$targetSuffix);
+ $dockerfile->run('chown -R '.self::WWW_DATA_USER_ID.':'.self::WWW_DATA_GROUP_ID.' /var/www/app');
+
$nginxConfig = $config->get('nginx-config');
if (!empty($nginxConfig)) {
$dockerfile->addVolume('/etc/nginx/conf.template.d');
|
changed user statement to chown on /var/www/app
|
diff --git a/lib/rest/routes/apps.js b/lib/rest/routes/apps.js
index <HASH>..<HASH> 100644
--- a/lib/rest/routes/apps.js
+++ b/lib/rest/routes/apps.js
@@ -25,7 +25,7 @@ module.exports = function () {
})
.then(app => res.json(app))
.catch(err => {
- if (err.message.indexOf('exists') >= 0) {
+ if (err.message.indexOf('exist') >= 0) {
res.status(409).send(err.message);
} else {
next(err);
|
Correctly spell error for the returned status code
|
diff --git a/.gitignore b/.gitignore
index <HASH>..<HASH> 100644
--- a/.gitignore
+++ b/.gitignore
@@ -27,3 +27,4 @@ _testmain.go
*.test
*.prof
+/.idea
diff --git a/mock_test.go b/mock_test.go
index <HASH>..<HASH> 100644
--- a/mock_test.go
+++ b/mock_test.go
@@ -124,3 +124,11 @@ func TestTimerResets(t *testing.T) {
c.AddTime(3 * time.Millisecond)
assertGets(t, tm.Chan(), "expected timer to get after reset when interval is up after restarted")
}
+
+func TestTickerDeadlock(t *testing.T) { // fixes #6
+ c := NewMockClock()
+ tk := c.NewTicker(5 * time.Millisecond)
+ c.AddTime(6 * time.Millisecond)
+ time.Sleep(1 * time.Millisecond)
+ tk.Stop()
+}
diff --git a/ticker.go b/ticker.go
index <HASH>..<HASH> 100644
--- a/ticker.go
+++ b/ticker.go
@@ -27,7 +27,11 @@ func (m *mockTicker) wait() {
case <-m.stop:
return
case <-m.clock.After(delta):
- m.c <- m.clock.Now()
+ select {
+ case m.c <- m.clock.Now():
+ case <-m.stop:
+ return
+ }
}
}
}
|
fix(ticker): deadlock on Close()
|
diff --git a/Form/ValidationTokenParser.php b/Form/ValidationTokenParser.php
index <HASH>..<HASH> 100644
--- a/Form/ValidationTokenParser.php
+++ b/Form/ValidationTokenParser.php
@@ -220,16 +220,10 @@ class ValidationTokenParser implements ValidationParser
}
$file->seek($lineNumber - 1);
- $contents = '<?php ';
+ $contents = '<?php ' . $file->current();
- while ($line = $file->fgets()) {
- $contents .= $line;
-
- if ($lineNumber === $class->getEndLine()) {
- break;
- }
-
- $lineNumber++;
+ while ($lineNumber++ < $class->getEndLine()) {
+ $contents .= $file->fgets();
}
return $contents;
|
Fix of ValidationTokenParser - stop on the last line of the class file. (#4)
Fix of ValidationTokenParser parsing incorrect lines
|
diff --git a/src/js/components/tooltip.js b/src/js/components/tooltip.js
index <HASH>..<HASH> 100644
--- a/src/js/components/tooltip.js
+++ b/src/js/components/tooltip.js
@@ -13,6 +13,8 @@ function plugin(UIkit) {
attrs: true,
+ args: 'title',
+
mixins: [mixin.container, mixin.togglable, mixin.position],
props: {
|
add `title` as primary option to tooltip
|
diff --git a/obdalib/obdalib-core/src/main/java/inf/unibz/it/obda/rdbmsgav/domain/RDBMSOBDAMappingAxiom.java b/obdalib/obdalib-core/src/main/java/inf/unibz/it/obda/rdbmsgav/domain/RDBMSOBDAMappingAxiom.java
index <HASH>..<HASH> 100644
--- a/obdalib/obdalib-core/src/main/java/inf/unibz/it/obda/rdbmsgav/domain/RDBMSOBDAMappingAxiom.java
+++ b/obdalib/obdalib-core/src/main/java/inf/unibz/it/obda/rdbmsgav/domain/RDBMSOBDAMappingAxiom.java
@@ -87,4 +87,13 @@ public class RDBMSOBDAMappingAxiom extends AbstractOBDAMappingAxiom {
return clone;
}
+
+ @Override
+ public String toString() {
+ StringBuffer bf = new StringBuffer();
+ bf.append(sourceQuery.toString());
+ bf.append(" ==> ");
+ bf.append(targetQuery.toString());
+ return bf.toString();
+ }
}
|
Added comments, logging, documentation and TO-DOs to the classes involved in query answering.
|
diff --git a/qtpylib/futures.py b/qtpylib/futures.py
index <HASH>..<HASH> 100644
--- a/qtpylib/futures.py
+++ b/qtpylib/futures.py
@@ -251,7 +251,10 @@ def get_contract_ticksize(symbol, fallback=0.01, ttl=84600):
# -------------------------------------------
-def make_tuple(symbol, expiry, exchange=None):
+def make_tuple(symbol, expiry=None, exchange=None):
+ if expiry == None:
+ expiry = get_active_contract(symbol)
+
contract = get_ib_futures(symbol, exchange)
if contract is not None:
return (contract['symbol'], "FUT", contract['exchange'], contract['currency'], expiry, 0.0, "")
|
auto selects most active contract expiry
...when no expiry is provided (CME Group Futures only)
|
diff --git a/App.php b/App.php
index <HASH>..<HASH> 100644
--- a/App.php
+++ b/App.php
@@ -65,6 +65,10 @@ class App
$editorLink = admin_url('options.php?page=modularity-editor&id=archive-' . $postType->rewrite['slug']);
}
+ if (is_home()) {
+ $editorLink = admin_url('options.php?page=modularity-editor&id=archive-post');
+ }
+
if (is_search()) {
$editorLink = admin_url('options.php?page=modularity-editor&id=search');
}
|
Fixes adminbar link to home
|
diff --git a/src/Common/Controller/Base.php b/src/Common/Controller/Base.php
index <HASH>..<HASH> 100644
--- a/src/Common/Controller/Base.php
+++ b/src/Common/Controller/Base.php
@@ -497,14 +497,8 @@ abstract class Base extends \MX_Controller
if (!$oRoutesService->update()) {
throw new NailsException('Failed to generate routes_app.php. ' . $oRoutesService->lastError(), 500);
} else {
-
- // Routes exist now, instruct the browser to try again
$oInput = Factory::service('Input');
- if ($oInput->post()) {
- redirect($oInput->server('REQUEST_URI'), 'Location', 307);
- } else {
- redirect($oInput->server('REQUEST_URI'));
- }
+ redirect($oInput->server('REQUEST_URI'), 'auto', 307);
}
}
}
|
Using <I> redirect for all route regeneration requests
|
diff --git a/assets/js/addons-materialise/picker.js b/assets/js/addons-materialise/picker.js
index <HASH>..<HASH> 100644
--- a/assets/js/addons-materialise/picker.js
+++ b/assets/js/addons-materialise/picker.js
@@ -81,7 +81,7 @@
onStop : false,
selectMonths : false,
selectYears : false,
- today : 'Today',
+ today : '',
weekdaysFull : ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
weekdaysShort : ['S', 'M', 'T', 'W', 'T', 'F', 'S']
}
|
Disable today button in picker by default
|
diff --git a/activerecord/lib/active_record/schema_dumper.rb b/activerecord/lib/active_record/schema_dumper.rb
index <HASH>..<HASH> 100644
--- a/activerecord/lib/active_record/schema_dumper.rb
+++ b/activerecord/lib/active_record/schema_dumper.rb
@@ -127,7 +127,7 @@ HEADER
end.compact
# find all migration keys used in this table
- keys = [:name, :limit, :precision, :scale, :default, :null] & column_specs.map(&:keys).flatten
+ keys = [:name, :limit, :precision, :scale, :default, :null]
# figure out the lengths for each column based on above keys
lengths = keys.map { |key|
|
just use the list of formatting keys we care about
|
diff --git a/gitignore.go b/gitignore.go
index <HASH>..<HASH> 100644
--- a/gitignore.go
+++ b/gitignore.go
@@ -47,6 +47,9 @@ func NewGitIgnoreFromReader(path string, r io.Reader) gitIgnore {
if len(line) == 0 || strings.HasPrefix(line, "#") {
continue
}
+ if strings.HasPrefix(line, `\#`) {
+ line = strings.TrimPrefix(line, `\`)
+ }
if strings.HasPrefix(line, "!") {
g.acceptPatterns.add(strings.TrimPrefix(line, "!"))
diff --git a/gitignore_test.go b/gitignore_test.go
index <HASH>..<HASH> 100644
--- a/gitignore_test.go
+++ b/gitignore_test.go
@@ -40,6 +40,7 @@ func TestMatch(t *testing.T) {
assert{[]string{"*.txt", "!b.txt"}, file{"dir/b.txt", false}, false},
assert{[]string{"dir/*.txt", "!dir/b.txt"}, file{"dir/b.txt", false}, false},
assert{[]string{"dir/*.txt", "!/b.txt"}, file{"dir/b.txt", false}, true},
+ assert{[]string{`\#a.txt`}, file{"#a.txt", false}, true},
}
for _, assert := range asserts {
|
Support escaped hash
gitignore document says
> A line starting with # serves as a comment. Put a backslash ("\") in front
> of the first hash for patterns that begin with a hash.
|
diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -39,8 +39,11 @@ function droonga(application, params) {
application.connectionPool = connectionPool;
if (params.syncHostNames &&
- typeof connectionPool.startSyncHostNamesFromCluster == 'function')
- connectionPool.startSyncHostNamesFromCluster();
+ typeof connectionPool.startSyncHostNamesFromCluster == 'function') {
+ params.server.on('listening', function() {
+ connectionPool.startSyncHostNamesFromCluster();
+ });
+ }
}
exports.initialize = droonga;
|
Start to connect the backend only when the server is correctly started
|
diff --git a/lib/raven/configuration.rb b/lib/raven/configuration.rb
index <HASH>..<HASH> 100644
--- a/lib/raven/configuration.rb
+++ b/lib/raven/configuration.rb
@@ -28,6 +28,9 @@ module Raven
# Which exceptions should never be sent
attr_accessor :excluded_exceptions
+ # Processors to run on data before sending upstream
+ attr_accessor :processors
+
attr_reader :current_environment
def initialize
@@ -37,6 +40,7 @@ module Raven
self.current_environment = ENV['RAILS_ENV'] || ENV['RACK_ENV'] || 'development'
self.send_modules = true
self.excluded_exceptions = []
+ self.processors = [Raven::Processor::SanitizeData]
end
def server=(value)
|
Allow processors to be registered, and install SanitizeData by default
|
diff --git a/salt/states/saltmod.py b/salt/states/saltmod.py
index <HASH>..<HASH> 100644
--- a/salt/states/saltmod.py
+++ b/salt/states/saltmod.py
@@ -349,11 +349,11 @@ def function(
ret['changes'] = {'ret': changes}
if fail:
ret['result'] = False
- ret['comment'] = 'Run failed on minions: {0}'.format(', '.join(fail))
+ ret['comment'] = 'Running function {0} failed on minions: {1}'.format(name, ', '.join(fail))
else:
- ret['comment'] = 'Functions ran successfully.'
+ ret['comment'] = 'Function ran successfully.'
if changes:
- ret['comment'] += ' Functions ran on {0}.'.format(', '.join(changes))
+ ret['comment'] += ' Function {0} ran on {1}.'.format(name, ', '.join(changes))
if failures:
ret['comment'] += '\nFailures:\n'
for minion, failure in failures.iteritems():
|
a bit more verbose
|
diff --git a/coursera/__init__.py b/coursera/__init__.py
index <HASH>..<HASH> 100644
--- a/coursera/__init__.py
+++ b/coursera/__init__.py
@@ -1 +1 @@
-__version__ = '0.9.0'
+__version__ = '0.10.0'
|
coursera: Update version number.
[ci skip]
|
diff --git a/gitreceive/receiver/flynn-receive.go b/gitreceive/receiver/flynn-receive.go
index <HASH>..<HASH> 100644
--- a/gitreceive/receiver/flynn-receive.go
+++ b/gitreceive/receiver/flynn-receive.go
@@ -31,7 +31,6 @@ func init() {
var typesPattern = regexp.MustCompile("types.* -> (.+)\n")
const blobstoreURL = "http://blobstore.discoverd"
-const scaleTimeout = 20 * time.Second
func parsePairs(args *docopt.Args, str string) (map[string]string, error) {
pairs := args.All[str].([]string)
@@ -224,7 +223,7 @@ Options:
}
fmt.Println("=====> Waiting for web job to start...")
- err = watcher.WaitFor(ct.JobEvents{"web": ct.JobUpEvents(1)}, scaleTimeout, func(e *ct.Job) error {
+ err = watcher.WaitFor(ct.JobEvents{"web": ct.JobUpEvents(1)}, time.Duration(app.DeployTimeout)*time.Second, func(e *ct.Job) error {
switch e.State {
case ct.JobStateUp:
fmt.Println("=====> Default web formation scaled to 1")
|
gitreceive/receiver: Use deploy timeout when waiting for web job
This typically happens on the first deploy of an app.
Closes #<I>
|
diff --git a/bcbio/structural/prioritize.py b/bcbio/structural/prioritize.py
index <HASH>..<HASH> 100644
--- a/bcbio/structural/prioritize.py
+++ b/bcbio/structural/prioritize.py
@@ -163,7 +163,10 @@ def _cnvkit_prioritize(sample, genes, allele_file, metrics_file):
adf = pd.read_table(allele_file)
if len(genes) > 0:
adf = adf[adf["gene"].str.contains("|".join(genes))]
- adf = adf[["chromosome", "start", "end", "cn", "cn1", "cn2"]]
+ if "cn1" in adf.columns and "cn2" in adf.columns:
+ adf = adf[["chromosome", "start", "end", "cn", "cn1", "cn2"]]
+ else:
+ adf = adf[["chromosome", "start", "end", "cn"]]
df = pd.merge(mdf, adf, on=["chromosome", "start", "end"])
df = df[df["cn"] != 2]
if len(df) > 0:
|
CNVkit: handle cases without allele copy numbers
Avoid failing if we could not use VCF input to infer allele specific
copy numbers.
|
diff --git a/src/main/java/hex/NeuralNet.java b/src/main/java/hex/NeuralNet.java
index <HASH>..<HASH> 100644
--- a/src/main/java/hex/NeuralNet.java
+++ b/src/main/java/hex/NeuralNet.java
@@ -38,7 +38,7 @@ public class NeuralNet extends ValidatedJob {
public Activation activation = Activation.Tanh;
@API(help = "Input layer dropout ratio", filter = Default.class, dmin = 0, dmax = 1, json = true)
- public double input_dropout_ratio = 0.2;
+ public double input_dropout_ratio = 0.0;
@API(help = "Hidden layer sizes, e.g. 1000, 1000. Grid search: (100, 100), (200, 200)", filter = Default.class, json = true)
public int[] hidden = new int[] { 200, 200 };
@@ -125,11 +125,6 @@ public class NeuralNet extends ValidatedJob {
arg.disable("Regression is not currently supported.");
}
if (arg._name.equals("ignored_cols")) arg.disable("Not currently supported.");
- if (arg._name.equals("input_dropout_ratio") &&
- (activation != Activation.RectifierWithDropout && activation != Activation.TanhWithDropout)
- ) {
- arg.disable("Only with Dropout.", inputArgs);
- }
if(arg._name.equals("initial_weight_scale") &&
(initial_weight_distribution == InitialWeightDistribution.UniformAdaptive)
) {
|
Default input dropout ratio to zero for NeuralNet (which now also allows input
dropout without using Dropout).
|
diff --git a/cake/tests/cases/libs/view/view.test.php b/cake/tests/cases/libs/view/view.test.php
index <HASH>..<HASH> 100644
--- a/cake/tests/cases/libs/view/view.test.php
+++ b/cake/tests/cases/libs/view/view.test.php
@@ -245,27 +245,6 @@ class ViewTest extends CakeTestCase {
$this->PostsController->viewPath = 'posts';
$this->PostsController->index();
$this->View = new View($this->PostsController);
- }
-
-/**
- * tearDown method
- *
- * @access public
- * @return void
- */
- function tearDown() {
- unset($this->View);
- unset($this->PostsController);
- unset($this->Controller);
- }
-
-/**
- * endTest
- *
- * @access public
- * @return void
- */
- function startTest() {
App::build(array(
'plugins' => array(TEST_CAKE_CORE_INCLUDE_PATH . 'tests' . DS . 'test_app' . DS . 'plugins' . DS),
'views' => array(
@@ -276,12 +255,15 @@ class ViewTest extends CakeTestCase {
}
/**
- * endTest
+ * tearDown method
*
* @access public
* @return void
*/
- function endTest() {
+ function tearDown() {
+ unset($this->View);
+ unset($this->PostsController);
+ unset($this->Controller);
App::build();
}
|
Moving logic from methods that will be probably deprecated
|
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -21,7 +21,7 @@ setup(
include_package_data = True,
- scripts = ['calloway/bin/generate_reqs',],
+ scripts = ['calloway/bin/generate_reqs','calloway/bin/check_for_updates'],
classifiers = [
'Development Status :: 4 - Beta',
'Environment :: Web Environment',
|
Added the new script to the setup.py so it is installed.
|
diff --git a/cheroot/test/test_core.py b/cheroot/test/test_core.py
index <HASH>..<HASH> 100644
--- a/cheroot/test/test_core.py
+++ b/cheroot/test/test_core.py
@@ -282,8 +282,8 @@ def test_content_length_required(test_client):
def test_large_request(test_client_with_defaults):
"""Test GET query with maliciously large Content-Length."""
# If the server's max_request_body_size is not set (i.e. is set to 0)
- # then this will result in an `OverflowError: Python int too large to convert to C ssize_t`
- # in the server.
+ # then this will result in an `OverflowError: Python int too large to
+ # convert to C ssize_t` in the server.
# We expect that this should instead return that the request is too
# large.
c = test_client_with_defaults.get_connection()
|
Wrap a line that's too long in test_core
Hotfix of a typo from PR #<I>
|
diff --git a/lib/driver.js b/lib/driver.js
index <HASH>..<HASH> 100644
--- a/lib/driver.js
+++ b/lib/driver.js
@@ -206,7 +206,7 @@ class IosDriver extends BaseDriver {
// if we have an ipa file, set it in opts
if (this.opts.app) {
- let ext = this.opts.app.substring(this.opts.app.length - 4).toLowerCase();
+ let ext = this.opts.app.substring(this.opts.app.length - 3).toLowerCase();
if (ext === 'ipa') {
this.opts.ipa = this.opts.app;
}
|
fix set in opts ipa file
fix incorrect substring
|
diff --git a/src/article/shared/FigureLabelGenerator.js b/src/article/shared/FigureLabelGenerator.js
index <HASH>..<HASH> 100644
--- a/src/article/shared/FigureLabelGenerator.js
+++ b/src/article/shared/FigureLabelGenerator.js
@@ -20,7 +20,7 @@ export default class FigureLabelGenerator {
}
getLabel (...defs) {
- if (!defs || defs.length === 0) return this.config.invalid
+ if (defs.length === 0) return this.config.invalid
// Note: normalizing args so that every def is a tuple
defs = defs.map(d => {
if (!isArray(d)) return [d]
diff --git a/src/kit/shared/throwMethodIsAbstract.js b/src/kit/shared/throwMethodIsAbstract.js
index <HASH>..<HASH> 100644
--- a/src/kit/shared/throwMethodIsAbstract.js
+++ b/src/kit/shared/throwMethodIsAbstract.js
@@ -1,3 +1,3 @@
-export function throwMethodIsAbstract () {
+export default function throwMethodIsAbstract () {
throw new Error('This method is abstract.')
}
|
Fix issues detected by lgtm.
|
diff --git a/src/Client.js b/src/Client.js
index <HASH>..<HASH> 100644
--- a/src/Client.js
+++ b/src/Client.js
@@ -621,8 +621,10 @@ class Client extends EventEmitter {
callback(err);
reject(err);
} else {
- if (self.getServer("id", res.body.guild.id)) {
- resolve(self.getServer("id", res.body.guild.id));
+ var server = self.getServer("id", res.body.guild.id);
+ if (server) {
+ callback(null, server);
+ resolve(server);
} else {
self.serverCreateListener[res.body.guild.id] = [resolve, callback];
}
|
Fix callback not being called in Client.joinServer
|
diff --git a/closure/goog/debug/debug.js b/closure/goog/debug/debug.js
index <HASH>..<HASH> 100644
--- a/closure/goog/debug/debug.js
+++ b/closure/goog/debug/debug.js
@@ -399,7 +399,8 @@ goog.debug.getStacktraceHelper_ = function(fn, visited) {
} else if (fn && visited.length < goog.debug.MAX_STACK_DEPTH) {
sb.push(goog.debug.getFunctionName(fn) + '(');
var args = fn.arguments;
- for (var i = 0; i < args.length; i++) {
+ // Args may be null for some special functions such as host objects or eval.
+ for (var i = 0; args && i < args.length; i++) {
if (i > 0) {
sb.push(', ');
}
|
At least in newish Chromes eval does not have an arguments properties, so the loop that is being patched here fails with an NPE.
This breaks i.e. the module manager were syntax errors in late loaded code can't be reported correctly.
-------------
Created by MOE: <URL>
|
diff --git a/src/main/java/water/util/MRUtils.java b/src/main/java/water/util/MRUtils.java
index <HASH>..<HASH> 100644
--- a/src/main/java/water/util/MRUtils.java
+++ b/src/main/java/water/util/MRUtils.java
@@ -319,11 +319,11 @@ public class MRUtils {
return sampleFrameStratified(fr, label, sampling_ratios, seed+1, debug, ++count);
}
- // shuffle intra-chunk
- Frame shuffled = shuffleFramePerChunk(r, seed+0x580FF13);
- r.delete();
-
- return shuffled;
+// // shuffle intra-chunk
+// Frame shuffled = shuffleFramePerChunk(r, seed + 0x580FF13);
+// r.delete();
+// return shuffled;
+ return r;
}
/**
|
Don't shuffle intra-chunk after stratified sampling.
|
diff --git a/lib/model.rb b/lib/model.rb
index <HASH>..<HASH> 100644
--- a/lib/model.rb
+++ b/lib/model.rb
@@ -22,6 +22,10 @@ module OpenTox
resource.post(self.to_yaml, :content_type => "application/x-yaml").chomp.to_s
end
+
+ def self.find_all
+ RestClient.get(@@config[:services]["opentox-model"]).chomp.split("\n")
+ end
=begin
include Owl
@@ -49,10 +53,6 @@ module OpenTox
lazar
end
- def self.find_all
- RestClient.get(@@config[:services]["opentox-model"]).split("\n")
- end
-
def self.find(uri)
yaml = RestClient.get(uri, :accept => "application/x-yaml")
OpenTox::Model::Lazar.from_yaml(yaml)
diff --git a/lib/task.rb b/lib/task.rb
index <HASH>..<HASH> 100644
--- a/lib/task.rb
+++ b/lib/task.rb
@@ -105,7 +105,7 @@ module OpenTox
def wait_for_completion
until self.completed? or self.failed?
- sleep 1
+ sleep 0.1
end
end
|
tests for yaml representation working
|
diff --git a/src/Client.php b/src/Client.php
index <HASH>..<HASH> 100644
--- a/src/Client.php
+++ b/src/Client.php
@@ -214,6 +214,9 @@ class Client {
if (! is_resource($ch) || ! $ret)
return false;
+ if (array_key_exists(CURLOPT_PROXY, $this->options) && version_compare(curl_version()['version'], '7.30.0', '<'))
+ list($headers, $ret) = preg_split('/\r\n\r\n|\r\r|\n\n/', $ret, 2);
+
$headers_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
if (is_numeric($headers_size) && $headers_size > 0) {
$headers = trim(substr($ret, 0, $headers_size));
|
Workaround for cURL < <I> bug with CURLINFO_HEADER_SIZE and proxies
|
diff --git a/util/settings/settings.go b/util/settings/settings.go
index <HASH>..<HASH> 100644
--- a/util/settings/settings.go
+++ b/util/settings/settings.go
@@ -368,7 +368,7 @@ const (
kustomizePathPrefixKey = "kustomize.path"
// anonymousUserEnabledKey is the key which enables or disables anonymous user
anonymousUserEnabledKey = "users.anonymous.enabled"
- // anonymousUserEnabledKey is the key which specifies token expiration duration
+ // userSessionDurationKey is the key which specifies token expiration duration
userSessionDurationKey = "users.session.duration"
// diffOptions is the key where diff options are configured
resourceCompareOptionsKey = "resource.compareoptions"
|
chore: fix typo in godoc string (#<I>)
While investigating how to disable the new terminal feature introduced in version <I>, came across this accidental copy/paste. Figured would boyscout it in.
|
diff --git a/exhale/__init__.py b/exhale/__init__.py
index <HASH>..<HASH> 100644
--- a/exhale/__init__.py
+++ b/exhale/__init__.py
@@ -8,7 +8,7 @@
from __future__ import unicode_literals
-__version__ = "0.2.1"
+__version__ = "0.2.2.dev"
def environment_ready(app):
|
there will be another minor release before 1.x
|
diff --git a/pyphi/distance.py b/pyphi/distance.py
index <HASH>..<HASH> 100644
--- a/pyphi/distance.py
+++ b/pyphi/distance.py
@@ -265,8 +265,8 @@ def intrinsic_difference(p, q):
*Sci Rep*, 10, 18803. https://doi.org/10.1038/s41598-020-75943-4
Args:
- p (float): The first probability distribution.
- q (float): The second probability distribution.
+ p (np.ndarray[float]): The first probability distribution.
+ q (np.ndarray[float]): The second probability distribution.
Returns:
float: The intrinsic difference.
@@ -289,8 +289,8 @@ def absolute_intrinsic_difference(p, q):
and references.
Args:
- p (float): The first probability distribution.
- q (float): The second probability distribution.
+ p (np.ndarray[float]): The first probability distribution.
+ q (np.ndarray[float]): The second probability distribution.
Returns:
float: The absolute intrinsic difference.
|
distance: Fix arg type in docstrings for ID
|
diff --git a/skpy/msg.py b/skpy/msg.py
index <HASH>..<HASH> 100644
--- a/skpy/msg.py
+++ b/skpy/msg.py
@@ -491,7 +491,16 @@ class SkypeCardMsg(SkypeMsg):
"text": self.body,
"buttons": [button.data for button in self.buttons]},
"contentType": "application/vnd.microsoft.card.hero"}],
- "type": "message/card"}
+ "type": "message/card",
+ "timestamp": datetime.now().strftime("%Y-%m-%dT%H:%M:%S.%fZ")}
+ if self.chatId:
+ data["recipient"] = {"id": self.chatId}
+ userType, userId = self.chatId.split(":", 1)
+ if userType == "19":
+ # Cards haven't been seen in group conversations yet, so assuming a sensible behaviour.
+ data["recipient"]["name"] = self.chat.topic
+ elif self.skype:
+ data["recipient"]["name"] = str(self.skype.contacts[userId].name)
b64 = base64.b64encode(json.dumps(data, separators=(",", ":")).encode("utf-8")).decode("utf-8")
tag = makeTag("URIObject", "Card - access it on ", type="SWIFT.1",
url_thumbnail="https://urlp.asm.skype.com/v1/url/content?url=https://"
|
Add timestamp and recipient to card HTML
Part of #<I>.
|
diff --git a/src/ApplicationBuilder.php b/src/ApplicationBuilder.php
index <HASH>..<HASH> 100644
--- a/src/ApplicationBuilder.php
+++ b/src/ApplicationBuilder.php
@@ -111,12 +111,14 @@ class ApplicationBuilder implements ApplicationBuilderInterface
*
* All the added global config paths will be merged in chronological order.
*
- * @param string $globalConfigPath
+ * @param string[] ...$globalConfigPaths
* @return ApplicationBuilder
*/
- public function addGlobalConfigPath(string $globalConfigPath): ApplicationBuilder
+ public function addGlobalConfigPath(string ...$globalConfigPaths): ApplicationBuilder
{
- $this->globalConfigPaths[] = $globalConfigPath;
+ foreach ($globalConfigPaths as $globalConfigPath) {
+ $this->globalConfigPaths[] = $globalConfigPath;
+ }
return $this;
}
@@ -124,12 +126,14 @@ class ApplicationBuilder implements ApplicationBuilderInterface
/**
* Add config loader.
*
- * @param LoaderInterface $loader
+ * @param LoaderInterface[] ...$loaders
* @return ApplicationBuilder
*/
- public function addConfig(LoaderInterface $loader): ApplicationBuilder
+ public function addConfig(LoaderInterface ...$loaders): ApplicationBuilder
{
- $this->configs[] = $loader;
+ foreach ($loaders as $loader) {
+ $this->configs[] = $loader;
+ }
return $this;
}
|
Added splat operator for config and global config path.
|
diff --git a/src/org/opencms/ui/login/CmsLoginController.java b/src/org/opencms/ui/login/CmsLoginController.java
index <HASH>..<HASH> 100644
--- a/src/org/opencms/ui/login/CmsLoginController.java
+++ b/src/org/opencms/ui/login/CmsLoginController.java
@@ -483,6 +483,9 @@ public class CmsLoginController {
return;
}
}
+ CmsObject cloneCms = OpenCms.initCmsObject(currentCms);
+ cloneCms.loginUser(realUser, password);
+
String messageToChange = "";
if (OpenCms.getLoginManager().isPasswordReset(currentCms, userObj)) {
messageToChange = CmsVaadinUtils.getMessageText(Messages.GUI_PWCHANGE_RESET_0);
@@ -502,9 +505,6 @@ public class CmsLoginController {
passwordDialog);
return;
}
- // do a provisional login first, to check the login target
- CmsObject cloneCms = OpenCms.initCmsObject(currentCms);
- cloneCms.loginUser(realUser, password);
CmsWorkplaceSettings settings = CmsLoginHelper.initSiteAndProject(cloneCms);
final String loginTarget = getLoginTarget(cloneCms, settings, m_params.getRequestedResource());
|
Fixed password check order for users which have to reset their password.
|
diff --git a/test/m-thrift.js b/test/m-thrift.js
index <HASH>..<HASH> 100644
--- a/test/m-thrift.js
+++ b/test/m-thrift.js
@@ -49,12 +49,17 @@ describe('thrift', function()
{
system.keyspace = 'system';
conn = new scamandrios.ConnectionPool(system);
- var promise = conn.connect().should.be.fulfilled;
- return promise.should.eventually.have.property('definition').then(function(keyspace)
- {
- return keyspace.definition.name;
- }).should.become('system');
+ var promise = conn.connect();
+ return P.all(
+ [
+ promise.should.be.fulfilled,
+ promise.should.eventually.be.an.instanceof(scamandrios.Keyspace),
+ promise.then(function(keyspace)
+ {
+ return keyspace.definition.name;
+ }).should.become('system')
+ ]);
});
it('bad pool connect', function()
|
Clean up the `Pool#connect` test.
|
diff --git a/src/components/Arrow.js b/src/components/Arrow.js
index <HASH>..<HASH> 100644
--- a/src/components/Arrow.js
+++ b/src/components/Arrow.js
@@ -60,7 +60,7 @@ const defaultStyles = {
userSelect: 'none',
},
- // sizees
+ // sizes
arrow__size__medium: {
height: defaults.arrow.height,
marginTop: defaults.arrow.height / -2,
diff --git a/src/theme.js b/src/theme.js
index <HASH>..<HASH> 100644
--- a/src/theme.js
+++ b/src/theme.js
@@ -45,7 +45,7 @@ theme.thumbnail = {
// arrow
theme.arrow = {
- background: 'black',
+ background: 'none',
fill: 'white',
height: 120,
};
|
default arrow bg to none and fix typo
|
diff --git a/lib/hook_runner.rb b/lib/hook_runner.rb
index <HASH>..<HASH> 100755
--- a/lib/hook_runner.rb
+++ b/lib/hook_runner.rb
@@ -2,7 +2,7 @@
require 'pathname'
unless File.symlink?(__FILE__)
- STDERR.puts "This file is not meant to be called directly."
+ STDERR.puts 'This file is not meant to be called directly.'
exit 2
end
|
Convert double to single quotes
For speed.
Change-Id: I7d<I>a<I>be4b0f<I>fa8cf<I>c<I>b5
Reviewed-on: <URL>
|
diff --git a/lib/mongoid_fulltext.rb b/lib/mongoid_fulltext.rb
index <HASH>..<HASH> 100644
--- a/lib/mongoid_fulltext.rb
+++ b/lib/mongoid_fulltext.rb
@@ -67,8 +67,8 @@ module Mongoid::FullTextSearch
index_definition = [['ngram', Mongo::ASCENDING], ['score', Mongo::DESCENDING]].concat(filter_indexes)
end
- coll.ensure_index(index_definition, name: 'fts_index')
- coll.ensure_index([['document_id', Mongo::ASCENDING]]) # to make removes fast
+ coll.ensure_index(index_definition, { name: 'fts_index', background: true })
+ coll.ensure_index([['document_id', Mongo::ASCENDING]], { background: true }) # to make removes fast
end
def fulltext_search(query_string, options={})
|
Changed ensure_index to index in the background, avoid blocking booting app.
|
diff --git a/gulpfile.js b/gulpfile.js
index <HASH>..<HASH> 100644
--- a/gulpfile.js
+++ b/gulpfile.js
@@ -57,18 +57,7 @@ function adminTasks() {
scss: pathto('stylesheets/scss/**/*.scss')
};
- gulp.task('jshint', function () {
- return gulp.src(scripts.all)
- .pipe(plugins.jshint())
- .pipe(plugins.jshint.reporter('default'));
- });
-
- gulp.task('jscs', function () {
- return gulp.src(scripts.all)
- .pipe(plugins.jscs());
- });
-
- gulp.task('qor', ['jshint', 'jscs'], function () {
+ gulp.task('qor', function () {
return gulp.src([scripts.qorInit,scripts.qor])
.pipe(plugins.concat('qor.js'))
.pipe(plugins.uglify())
|
fix(gulp): remove jshint and jscs for adminTask
|
diff --git a/src/main/java/com/conveyal/gtfs/graphql/GraphQLGtfsSchema.java b/src/main/java/com/conveyal/gtfs/graphql/GraphQLGtfsSchema.java
index <HASH>..<HASH> 100644
--- a/src/main/java/com/conveyal/gtfs/graphql/GraphQLGtfsSchema.java
+++ b/src/main/java/com/conveyal/gtfs/graphql/GraphQLGtfsSchema.java
@@ -292,6 +292,7 @@ public class GraphQLGtfsSchema {
.field(newFieldDefinition()
.name("trips")
.type(new GraphQLList(tripType))
+ .argument(multiStringArg("service_id"))
.dataFetcher(new JDBCFetcher("trips", "pattern_id"))
.build())
.build();
|
add service_id arg to filter trips
|
diff --git a/examples/books_collection/collection/views.py b/examples/books_collection/collection/views.py
index <HASH>..<HASH> 100644
--- a/examples/books_collection/collection/views.py
+++ b/examples/books_collection/collection/views.py
@@ -17,6 +17,12 @@ def list_books(page=1):
pagination = Book.query.paginate(page=page, per_page=5)
return render_template('/books/list.html', pagination=pagination)
+@app.route('/books/<letter>')
+@app.route('/books/<letter>/<int:page>')
+def list_books_filtering(letter, page=1):
+ pagination = Book.query.starting_with(letter).paginate(page=page, per_page=5)
+ return render_template('/books/list.html', pagination=pagination)
+
@app.route('/books/delete/<id>')
def delete_book(id):
book = Book.query.get_or_404(id)
|
Added a URL and view for get books by their first letter
|
diff --git a/src/cache.js b/src/cache.js
index <HASH>..<HASH> 100644
--- a/src/cache.js
+++ b/src/cache.js
@@ -38,6 +38,14 @@ module.exports.configure = function(options) {
reqBody.push(lastChunk);
}
+ reqBody = reqBody.map(function (chunk) {
+ if (!Buffer.isBuffer(chunk)) {
+ return new Buffer(chunk);
+ } else {
+ return chunk;
+ }
+ });
+
reqBody = Buffer.concat(reqBody);
var filename = sepiaUtil.constructFilename(options.method, reqUrl,
reqBody.toString(), options.headers);
|
Make fixture record work with non-Buffers
|
diff --git a/test/schemaTest.js b/test/schemaTest.js
index <HASH>..<HASH> 100644
--- a/test/schemaTest.js
+++ b/test/schemaTest.js
@@ -36,7 +36,7 @@ var schema = {
var formats = {
foo: function foo(Faker, schema) {
- return Faker.Name.firstName();
+ return Faker.name.firstName();
},
Bar: function foo(Faker, schema) {
return 'BAR';
|
Fixed Faker issue running test/schema.js
|
diff --git a/src/main/java/com/lmax/disruptor/RingBuffer.java b/src/main/java/com/lmax/disruptor/RingBuffer.java
index <HASH>..<HASH> 100644
--- a/src/main/java/com/lmax/disruptor/RingBuffer.java
+++ b/src/main/java/com/lmax/disruptor/RingBuffer.java
@@ -336,11 +336,16 @@ public final class RingBuffer<E> extends RingBufferFields<E> implements Cursored
}
/**
- * Determines if a particular entry has been published.
+ * Determines if a particular entry is available. Note that using this when not within a context that is
+ * maintaining a sequence barrier, it is likely that using this to determine if you can read a value is likely
+ * to result in a race condition and broken code.
*
* @param sequence The sequence to identify the entry.
- * @return If the value has been published or not.
+ * @return If the value can be read or not.
+ * @deprecated Please don't use this method. It probably won't
+ * do what you think that it does.
*/
+ @Deprecated
public boolean isPublished(long sequence)
{
return sequencer.isAvailable(sequence);
|
Make isPublished method as deprecated.
|
diff --git a/rllib/agents/trainer.py b/rllib/agents/trainer.py
index <HASH>..<HASH> 100644
--- a/rllib/agents/trainer.py
+++ b/rllib/agents/trainer.py
@@ -1225,7 +1225,7 @@ class Trainer(Trainable):
"larger value.".format(config["evaluation_num_workers"]))
config["evaluation_interval"] = 1
elif config["evaluation_num_workers"] == 0 and \
- config["evaluation_parallel_to_training"]:
+ config.get("evaluation_parallel_to_training", False):
logger.warning(
"`evaluation_parallel_to_training` can only be done if "
"`evaluation_num_workers` > 0! Setting "
|
[RLlib] Evaluation parallel to training check, key-error hotfix (#<I>)
|
diff --git a/functional/util.py b/functional/util.py
index <HASH>..<HASH> 100644
--- a/functional/util.py
+++ b/functional/util.py
@@ -18,7 +18,7 @@ if six.PY2:
PROTOCOL = 2
else:
CSV_WRITE_MODE = 'w'
- PROTOCOL = 4
+ PROTOCOL = serializer.HIGHEST_PROTOCOL
CPU_COUNT = cpu_count()
@@ -161,11 +161,12 @@ def lazy_parallelize(func, result, processes=None):
chunk_size = (len(result) // processes) or processes
except TypeError:
chunk_size = processes
- with Pool(processes=processes) as pool:
- chunks = split_every(chunk_size, iter(result))
- packed_chunks = (pack(func, (chunk, )) for chunk in chunks)
- for pool_result in pool.imap(unpack, packed_chunks):
- yield pool_result
+ pool = Pool(processes=processes)
+ chunks = split_every(chunk_size, iter(result))
+ packed_chunks = (pack(func, (chunk, )) for chunk in chunks)
+ for pool_result in pool.imap(unpack, packed_chunks):
+ yield pool_result
+ pool.terminate()
def compose(*functions):
|
Change pickling protocol to HIGHEST_PROTOCOL for Python3. Take out Pool from the context manager for Python2.
|
diff --git a/src/Spatie/GoogleSearch/GoogleSearch.php b/src/Spatie/GoogleSearch/GoogleSearch.php
index <HASH>..<HASH> 100644
--- a/src/Spatie/GoogleSearch/GoogleSearch.php
+++ b/src/Spatie/GoogleSearch/GoogleSearch.php
@@ -53,6 +53,10 @@ class GoogleSearch implements GoogleSearchInterface
$xml = simplexml_load_string($result->getBody());
+ if ($xml->ERROR) {
+ throw new Exception('XML indicated service error: '.$xml->ERROR);
+ }
+
if ($xml->RES->R) {
$i = 0;
foreach ($xml->RES->R as $item) {
|
Check XML for error condition.
|
diff --git a/src/lib/KevinGH/Box/Configuration.php b/src/lib/KevinGH/Box/Configuration.php
index <HASH>..<HASH> 100644
--- a/src/lib/KevinGH/Box/Configuration.php
+++ b/src/lib/KevinGH/Box/Configuration.php
@@ -471,6 +471,10 @@ class Configuration
public function getMetadata()
{
if (isset($this->raw->metadata)) {
+ if (is_object($this->raw->metadata)) {
+ return (array) $this->raw->metadata;
+ }
+
return $this->raw->metadata;
}
}
|
Restoring <I> metadata behavior.
In <I>, the way JSON data is decoded has changed to keep objects as objects. In <I>, objects were converted to associative arrays. For backwards compatibility, this behavior is being brought back.
|
diff --git a/client/js/KeyboardManager.js b/client/js/KeyboardManager.js
index <HASH>..<HASH> 100644
--- a/client/js/KeyboardManager.js
+++ b/client/js/KeyboardManager.js
@@ -103,11 +103,13 @@ define(['logManager'], function (logManager) {
if (this._listener !== l) {
this._listener = l;
- if (!this._listener.onKeyDown) {
- this._logger.warning('Listener is missing "onKeyDown"...');
- }
- if (!this._listener.onKeyUp) {
- this._logger.warning('Listener is missing "onKeyUp"...');
+ if (this._listener) {
+ if (!this._listener.onKeyDown) {
+ this._logger.warning('Listener is missing "onKeyDown"...');
+ }
+ if (!this._listener.onKeyUp) {
+ this._logger.warning('Listener is missing "onKeyUp"...');
+ }
}
}
};
|
bugfix: don't call method on undefined listener
Former-commit-id: e<I>b<I>d5e<I>b9f6e<I>ecf<I>bd5f<I>c3d<I>adf
|
diff --git a/bin/inline_forms_installer_core.rb b/bin/inline_forms_installer_core.rb
index <HASH>..<HASH> 100755
--- a/bin/inline_forms_installer_core.rb
+++ b/bin/inline_forms_installer_core.rb
@@ -508,7 +508,7 @@ copy_file File.join(GENERATOR_PATH,'lib/generators/templates/unicorn/production.
say "- adding and committing to git..."
git add: "."
-git commit: "-a -m Initial Commit"
+git commit: " -a -m 'Initial Commit'"
# example
if ENV['install_example'] == 'true'
|
upgrade Gemfile, gemspec and delete some files
|
diff --git a/lark/lark.py b/lark/lark.py
index <HASH>..<HASH> 100644
--- a/lark/lark.py
+++ b/lark/lark.py
@@ -202,7 +202,7 @@ class Lark:
if rel_to:
basepath = os.path.dirname(rel_to)
grammar_filename = os.path.join(basepath, grammar_filename)
- with open(grammar_filename) as f:
+ with open(grammar_filename, encoding='utf8') as f:
return cls(f, **options)
def __repr__(self):
|
Lark grammars are now utf8 by default (Issue #<I>)
|
diff --git a/bundles/org.eclipse.orion.client.core/static/js/coding/coding.js b/bundles/org.eclipse.orion.client.core/static/js/coding/coding.js
index <HASH>..<HASH> 100644
--- a/bundles/org.eclipse.orion.client.core/static/js/coding/coding.js
+++ b/bundles/org.eclipse.orion.client.core/static/js/coding/coding.js
@@ -125,10 +125,6 @@ dojo.addOnLoad(function(){
});
};
- var contentAssistFactory = function(editor) {
- return new eclipse.ContentAssist(editor, "contentassist");
- };
-
var inputManager = {
lastFilePath: "",
|
Looks like I busted content assist while merging my multi-file client changes. This should fix it.
|
diff --git a/src/Route.php b/src/Route.php
index <HASH>..<HASH> 100644
--- a/src/Route.php
+++ b/src/Route.php
@@ -38,15 +38,19 @@ class Route implements IRouter
*
* @param \Nette\Http\IRequest $httpRequest
*
- * @return \Nette\Application\Request|NULL
+ * @return Request|NULL
*/
public function match(Nette\Http\IRequest $httpRequest)
{
+ $path = $httpRequest->getUrl()->getPath();
+
if (!$this->isHttpMethodSupported($httpRequest->getMethod())) {
return NULL;
}
-
- //TODO: route matching..
+
+ if ($path !== $this->route) {
+ return NULL;
+ }
return new Request(
$this->presenterClassName,
@@ -62,7 +66,11 @@ class Route implements IRouter
/**
* Constructs absolute URL from Request object.
*
- * @return string|NULL
+ * @param Request $appRequest
+ * @param \Nette\Http\Url $refUrl
+ *
+ * @return NULL|string
+ * @throws \Exception
*/
function constructUrl(Request $appRequest, Nette\Http\Url $refUrl)
{
|
Added basic matching for urls
|
diff --git a/src/Google/Service/Logging.php b/src/Google/Service/Logging.php
index <HASH>..<HASH> 100644
--- a/src/Google/Service/Logging.php
+++ b/src/Google/Service/Logging.php
@@ -51,6 +51,7 @@ class Google_Service_Logging extends Google_Service
public function __construct(Google_Client $client)
{
parent::__construct($client);
+ $this->rootUrl = 'https://logging.googleapis.com/';
$this->servicePath = '';
$this->version = 'v1beta3';
$this->serviceName = 'logging';
|
Updated Logging.php
This change has been generated by a script that has detected changes in the
discovery doc of the API.
Check <URL>
|
diff --git a/library.js b/library.js
index <HASH>..<HASH> 100644
--- a/library.js
+++ b/library.js
@@ -342,7 +342,7 @@ Mentions.split = function(input, isMarkdown, splitBlockquote, splitCode) {
return [];
}
- var matchers = [isMarkdown ? '\\[.*?\\]\\(.*?\\)' : '<a[\\s\\S]*?</a>'];
+ var matchers = [isMarkdown ? '\\[.*?\\]\\(.*?\\)' : '<a[\\s\\S]*?</a>|<[^>]+>'];
if (splitBlockquote) {
matchers.push(isMarkdown ? '^>.*$' : '^<blockquote>.*?</blockquote>');
}
|
Fix mentions being replaced within HTML attributes
|
diff --git a/tests/integ/test_horovod.py b/tests/integ/test_horovod.py
index <HASH>..<HASH> 100644
--- a/tests/integ/test_horovod.py
+++ b/tests/integ/test_horovod.py
@@ -30,7 +30,7 @@ horovod_dir = os.path.join(os.path.dirname(__file__), "..", "data", "horovod")
@pytest.fixture(scope="module")
def gpu_instance_type(request):
- return "ml.p3.2xlarge"
+ return "ml.p2.xlarge"
@pytest.mark.canary_quick
@@ -40,7 +40,7 @@ def test_hvd_cpu(sagemaker_session, cpu_instance_type, tmpdir):
@pytest.mark.canary_quick
@pytest.mark.skipif(
- integ.test_region() in integ.HOSTING_NO_P3_REGIONS, reason="no ml.p3 instances in this region"
+ integ.test_region() in integ.HOSTING_NO_P2_REGIONS, reason="no ml.p2 instances in this region"
)
def test_hvd_gpu(sagemaker_session, gpu_instance_type, tmpdir):
__create_and_fit_estimator(sagemaker_session, gpu_instance_type, tmpdir)
|
change: use p2 instead of p3 for the Horovod test (#<I>)
|
diff --git a/gui/src/main/java/org/jboss/as/console/client/core/message/MessageCenterView.java b/gui/src/main/java/org/jboss/as/console/client/core/message/MessageCenterView.java
index <HASH>..<HASH> 100644
--- a/gui/src/main/java/org/jboss/as/console/client/core/message/MessageCenterView.java
+++ b/gui/src/main/java/org/jboss/as/console/client/core/message/MessageCenterView.java
@@ -230,6 +230,7 @@ public class MessageCenterView implements MessageCenter.MessageListener, ReloadE
messageButton.addClickHandler(clickHandler);
messageDisplay = new HorizontalPanel();
+ messageDisplay.getElement().setAttribute("role", "alert");
layout.add(messageDisplay);
layout.add(messageButton);
|
provide aria alert role for notificiations
|
diff --git a/dropwizard/src/main/java/com/yammer/dropwizard/json/JsonSnakeCase.java b/dropwizard/src/main/java/com/yammer/dropwizard/json/JsonSnakeCase.java
index <HASH>..<HASH> 100644
--- a/dropwizard/src/main/java/com/yammer/dropwizard/json/JsonSnakeCase.java
+++ b/dropwizard/src/main/java/com/yammer/dropwizard/json/JsonSnakeCase.java
@@ -12,7 +12,7 @@ import java.lang.annotation.Target;
* serialized and deserialized using {@code snake_case} JSON field names instead
* of {@code camelCase} field names.
*/
-@Target({ElementType.TYPE})
+@Target(ElementType.TYPE)
@Retention(RetentionPolicy.RUNTIME)
@JacksonAnnotation
public @interface JsonSnakeCase {
|
Simplify annotation in JsonSnakeCase.
|
diff --git a/lib/helpers/async.js b/lib/helpers/async.js
index <HASH>..<HASH> 100644
--- a/lib/helpers/async.js
+++ b/lib/helpers/async.js
@@ -7,7 +7,6 @@ var helper = require('async-helper-base');
*/
module.exports = function async_(verb) {
- verb.asyncHelper('apidocs', require('template-helper-apidocs')(verb));
verb.asyncHelper('reflinks', require('helper-reflinks'));
verb.asyncHelper('related', require('helper-related')());
verb.asyncHelper('include', helper('include'));
diff --git a/lib/helpers/sync.js b/lib/helpers/sync.js
index <HASH>..<HASH> 100644
--- a/lib/helpers/sync.js
+++ b/lib/helpers/sync.js
@@ -5,6 +5,7 @@
*/
module.exports = function sync_(verb) {
+ verb.helper('apidocs', require('template-helper-apidocs'));
verb.helper('codelinks', require('verb-helper-codelinks'));
verb.helper('changelog', require('helper-changelog'));
verb.helper('copyright', require('helper-copyright'));
|
register apidocs as a sync helper
|
diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -1,3 +1 @@
-
-
module.exports = require('./inject')()
diff --git a/inject.js b/inject.js
index <HASH>..<HASH> 100644
--- a/inject.js
+++ b/inject.js
@@ -33,6 +33,14 @@ module.exports = function (name, override) {
gossip: {
connections: 3
},
+ connections: {
+ incoming: {
+ net: [{ port: 8008, host: "localhost", scope: "local", "transform": "shs" }]
+ },
+ outgoing: {
+ net: [{ transform: "shs" }]
+ }
+ },
path: path.join(HOME, '.' + name),
timers: {
connection: 0,
|
Add connections transport/transform selection used in secret-stack
|
diff --git a/tests/Work/User/ClientTest.php b/tests/Work/User/ClientTest.php
index <HASH>..<HASH> 100644
--- a/tests/Work/User/ClientTest.php
+++ b/tests/Work/User/ClientTest.php
@@ -50,7 +50,7 @@ class ClientTest extends TestCase
public function testBatchDelete()
{
$client = $this->mockApiClient(Client::class);
- $client->expects()->httpPost('cgi-bin/user/batchdelete', ['useridlist' => ['overtrue', 'foo']])->andReturn('mock-result')->once();
+ $client->expects()->httpPostJson('cgi-bin/user/batchdelete', ['useridlist' => ['overtrue', 'foo']])->andReturn('mock-result')->once();
$this->assertSame('mock-result', $client->batchDelete(['overtrue', 'foo']));
}
|
Fix test (#<I>)
|
diff --git a/src/ChrisKonnertz/DeepLy/Protocol/ProtocolInterface.php b/src/ChrisKonnertz/DeepLy/Protocol/ProtocolInterface.php
index <HASH>..<HASH> 100644
--- a/src/ChrisKonnertz/DeepLy/Protocol/ProtocolInterface.php
+++ b/src/ChrisKonnertz/DeepLy/Protocol/ProtocolInterface.php
@@ -18,5 +18,15 @@ interface ProtocolInterface
* @return string
*/
public function createRequestData(array $payload, $method);
-
+
+ /**
+ * Processes the data from an response from the server to an API call.
+ * Returns the payload (data) of the response or throws a ProtocolException.
+ *
+ * @param string $rawResponseData The data (payload) of the response as a stringified JSON string
+ * @return \stdClass The data (payload) of the response as an object structure
+ * @throws ProtocolException|\InvalidArgumentException
+ */
+ public function processResponseData($rawResponseData);
+
}
|
Adjusted interface so it also has the processResponseData() method
|
diff --git a/java/messaging/messaging-common/src/main/java/io/joynr/messaging/routing/RoutingTableImpl.java b/java/messaging/messaging-common/src/main/java/io/joynr/messaging/routing/RoutingTableImpl.java
index <HASH>..<HASH> 100644
--- a/java/messaging/messaging-common/src/main/java/io/joynr/messaging/routing/RoutingTableImpl.java
+++ b/java/messaging/messaging-common/src/main/java/io/joynr/messaging/routing/RoutingTableImpl.java
@@ -141,10 +141,10 @@ public class RoutingTableImpl implements RoutingTable {
participantId,
address,
isGloballyVisible,
- address,
- isGloballyVisible,
expiryDateMs,
- sticky);
+ sticky,
+ result.address,
+ result.isGloballyVisible);
} else {
// address and isGloballyVisible are identical
|
[Java] Fix log output in RoutingTable if routing entry already exists
Change-Id: I<I>f<I>f<I>df<I>ab<I>a<I>d6d8ccbf3c
|
diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -113,6 +113,7 @@ module.exports = function (paths, opts) {
function listener(evt, evtPath) {
if (evt === 'create' || evt === 'update') {
fs.stat(evtPath, function(err, stat) {
+ if (err) { console.error(err); return; }
if (stat.isFile()) {
onFile(evtPath, stat);
} else if (stat.isDirectory() && evt === 'create') { //Do we even get "update" events for directories?
@@ -160,6 +161,7 @@ module.exports = function (paths, opts) {
path: baseFilePath,
listener: listener,
next: function(err, watcher) {
+ if (err) { throw err; }
watchers.push(watcher);
checkReady();
},
|
Check a few more error params
|
diff --git a/blockstore/lib/config.py b/blockstore/lib/config.py
index <HASH>..<HASH> 100644
--- a/blockstore/lib/config.py
+++ b/blockstore/lib/config.py
@@ -645,6 +645,7 @@ def default_bitcoind_opts( config_file=None ):
bitcoind_passwd = None
bitcoind_use_https = None
bitcoind_mock = False
+ bitcoind_timeout = 300
loaded = False
@@ -677,6 +678,9 @@ def default_bitcoind_opts( config_file=None ):
else:
mock = 'no'
+ if parser.has_option('bitcoind', 'timeout'):
+ bitcoind_timeout = parser.get('bitcoind', 'timeout')
+
if use_https.lower() in ["yes", "y", "true"]:
bitcoind_use_https = True
else:
@@ -711,7 +715,8 @@ def default_bitcoind_opts( config_file=None ):
"bitcoind_server": bitcoind_server,
"bitcoind_port": bitcoind_port,
"bitcoind_use_https": bitcoind_use_https,
- "bitcoind_mock": bitcoind_mock
+ "bitcoind_mock": bitcoind_mock,
+ "bitcoind_timeout": bitcoind_timeout
}
# strip None's
|
Read bitcoind timeout from config file
|
diff --git a/mod/quiz/lib.php b/mod/quiz/lib.php
index <HASH>..<HASH> 100644
--- a/mod/quiz/lib.php
+++ b/mod/quiz/lib.php
@@ -537,7 +537,7 @@ function quiz_print_recent_mod_activity($activity, $course, $detail=false) {
}
- if (has_capability('mod/quiz:grade', get_context_instance(CONTEXT_MODULE, $course))) {
+ if (has_capability('mod/quiz:grade', get_context_instance(CONTEXT_MODULE, $activity->instance))) {
$grades = "(" . $activity->content->sumgrades . " / " . $activity->content->maxgrade . ") ";
echo "<a href=\"$CFG->wwwroot/mod/quiz/review.php?q="
. $activity->instance . "&attempt="
|
MDL-<I> - Bogus get_context_instance call in quiz_print_recent_mod_activity. Merged from MOODLE_<I>_STABLE.
|
diff --git a/SoftLayer/API.py b/SoftLayer/API.py
index <HASH>..<HASH> 100644
--- a/SoftLayer/API.py
+++ b/SoftLayer/API.py
@@ -169,8 +169,8 @@ class Client(object):
'Content-Type': 'application/xml',
}
- if compress:
- http_headers['Accept-Encoding'] = 'deflate, compress, gzip'
+ if not compress:
+ http_headers['Accept-Encoding'] = ''
if raw_headers:
http_headers.update(raw_headers)
diff --git a/SoftLayer/transports.py b/SoftLayer/transports.py
index <HASH>..<HASH> 100644
--- a/SoftLayer/transports.py
+++ b/SoftLayer/transports.py
@@ -41,6 +41,8 @@ def make_xml_rpc_api_call(uri, method, args=None, headers=None,
response = requests.post(uri, data=payload,
headers=http_headers,
timeout=timeout)
+ log.debug(response.request.headers)
+ log.debug(response.headers)
log.debug(response.content)
response.raise_for_status()
result = xmlrpclib.loads(response.content,)[0][0]
|
Inverted compress flag behavior as requests compresses by default
|
diff --git a/binance/client.py b/binance/client.py
index <HASH>..<HASH> 100755
--- a/binance/client.py
+++ b/binance/client.py
@@ -949,8 +949,6 @@ class Client(BaseClient):
:type end_str: None|str|int
:param limit: Default 500; max 1000.
:type limit: int
- :param limit: Default 500; max 1000.
- :type limit: int
:param klines_type: Historical klines type: SPOT or FUTURES
:type klines_type: HistoricalKlinesType
|
Update client.py
Typo in docstring of _historical_klines
|
diff --git a/src/com/nexmo/verify/sdk/NexmoVerifyClient.java b/src/com/nexmo/verify/sdk/NexmoVerifyClient.java
index <HASH>..<HASH> 100644
--- a/src/com/nexmo/verify/sdk/NexmoVerifyClient.java
+++ b/src/com/nexmo/verify/sdk/NexmoVerifyClient.java
@@ -131,7 +131,15 @@ public class NexmoVerifyClient {
*/
private static final int MAX_SEARCH_REQUESTS = 10;
- private static final DateFormat sDateTimePattern = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+ private static final ThreadLocal<SimpleDateFormat> sDateTimePattern = new ThreadLocal<SimpleDateFormat>() {
+ @Override
+ protected SimpleDateFormat initialValue() {
+ SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
+ sdf.setLenient(false);
+
+ return sdf;
+ }
+ };
private final DocumentBuilderFactory documentBuilderFactory;
private final DocumentBuilder documentBuilder;
@@ -767,7 +775,7 @@ public class NexmoVerifyClient {
}
private static Date parseDateTime(String str) throws ParseException {
- return sDateTimePattern.parse(str);
+ return sDateTimePattern.get().parse(str);
}
}
|
thread safety - use thread local for shared date format
|
diff --git a/src/main/java/edu/washington/cs/knowitall/commonlib/logic/LogicExpression.java b/src/main/java/edu/washington/cs/knowitall/commonlib/logic/LogicExpression.java
index <HASH>..<HASH> 100644
--- a/src/main/java/edu/washington/cs/knowitall/commonlib/logic/LogicExpression.java
+++ b/src/main/java/edu/washington/cs/knowitall/commonlib/logic/LogicExpression.java
@@ -50,9 +50,17 @@ public class LogicExpression<E> implements Predicate<E> {
List<Tok> tokens = tokenize(input, factory);
expression = compile(tokens);
}
+
+ public boolean isEmpty() {
+ return this.expression.size() == 0;
+ }
@SuppressWarnings("unchecked")
public boolean apply(E target) {
+ if (this.isEmpty()) {
+ return true;
+ }
+
Stack<Tok> stack = new Stack<Tok>();
for (Tok tok : expression) {
if (tok instanceof Tok.Arg<?>) {
|
Added LogicExpression.isEmpty and made is so when empty LogicExpressions are applied the result is true.
|
diff --git a/src/build/browser.js b/src/build/browser.js
index <HASH>..<HASH> 100644
--- a/src/build/browser.js
+++ b/src/build/browser.js
@@ -39,8 +39,8 @@ function minify (ctx, task) {
return fs.readFile(path.join(process.cwd(), 'dist', 'index.js'))
.then((code) => {
const result = Uglify.minify(code.toString(), {
- mangle: false,
- compress: false
+ mangle: true,
+ compress: { unused: false }
})
if (result.error) {
throw result.error
|
feat: enable uglify mangle and compress
|
diff --git a/lib/specinfra/version.rb b/lib/specinfra/version.rb
index <HASH>..<HASH> 100644
--- a/lib/specinfra/version.rb
+++ b/lib/specinfra/version.rb
@@ -1,3 +1,3 @@
module Specinfra
- VERSION = "2.27.0"
+ VERSION = "2.27.1"
end
|
Bump up version
[skip ci]
|
diff --git a/addon/services/tour-manager.js b/addon/services/tour-manager.js
index <HASH>..<HASH> 100644
--- a/addon/services/tour-manager.js
+++ b/addon/services/tour-manager.js
@@ -189,7 +189,12 @@ export default Service.extend({
}
let lsKey = get(this, '_localStorageKey');
- let lsData = window.localStorage.getItem(lsKey);
+ let lsData = null;
+ try {
+ lsData = window.localStorage.getItem(lsKey);
+ } catch (e) {
+ console.error('Could not read from local storage.', e);
+ }
if (!lsData) {
return false;
}
@@ -219,7 +224,13 @@ export default Service.extend({
lsData = {};
}
lsData[id] = isRead;
- window.localStorage.setItem(lsKey, JSON.stringify(lsData));
+
+ try {
+ window.localStorage.setItem(lsKey, JSON.stringify(lsData));
+ } catch (e) {
+ console.error('Could not save to local storage.', e);
+ }
+
},
/**
|
Catch error if LocalStorage is not available
|
diff --git a/tests/FunctionalTestCase.php b/tests/FunctionalTestCase.php
index <HASH>..<HASH> 100644
--- a/tests/FunctionalTestCase.php
+++ b/tests/FunctionalTestCase.php
@@ -28,7 +28,7 @@ class FunctionalTestCase extends \Orchestra\Testbench\TestCase
/**
* {@inheritdoc}
*/
- public function setUp()
+ public function setUp(): void
{
parent::setUp();
|
fix: FunctionalTestCase
|
diff --git a/yii2instafeed.php b/yii2instafeed.php
index <HASH>..<HASH> 100644
--- a/yii2instafeed.php
+++ b/yii2instafeed.php
@@ -33,7 +33,7 @@ class yii2instafeed extends Widget
*/
public $clientOptions = array(
'get' => 'tagged',
- 'target' => '#instafeedid',
+ 'target' => '#instafeedtarget',
'tagName' => 'awesome',
'userId' => 'abcded',
'accessToken' => '123456_abcedef',
|
upgrade to correct target widget id
|
diff --git a/lib/hare/runner.rb b/lib/hare/runner.rb
index <HASH>..<HASH> 100644
--- a/lib/hare/runner.rb
+++ b/lib/hare/runner.rb
@@ -110,7 +110,7 @@ module Hare
exch = b.exchange(eopts[:name], :type => eopts[:type])
if @options[:publish]
- exch.publish(@arguments[0], :key => amqp[:key])
+ exch.publish(@arguments[0].rstrip + "\n", :key => amqp[:key])
else
q = b.queue(amqp[:queue])
q.bind(exch, :key => amqp[:key])
diff --git a/lib/hare/version.rb b/lib/hare/version.rb
index <HASH>..<HASH> 100644
--- a/lib/hare/version.rb
+++ b/lib/hare/version.rb
@@ -1,3 +1,3 @@
module Hare
- VERSION = "1.0.2"
+ VERSION = "1.0.3"
end
|
Cause hare to add a newline to payload messages.
If payloads are delivered to Unix programs through STDIN they will
expect a newline character to terminate the message. While the
originator of the payload might add a newline, it's not impossible
that they will fail to or not understand the need. hare strives to be
a good Unix tool, so the newline is added by default.
|
diff --git a/lib/challah.rb b/lib/challah.rb
index <HASH>..<HASH> 100644
--- a/lib/challah.rb
+++ b/lib/challah.rb
@@ -60,7 +60,7 @@ module Challah
end
def self.user
- @user ||= options[:user].to_s.safe_constantize
+ options[:user].to_s.safe_constantize
end
# Set up techniques engines
|
Remove caching on the user model
In development mode when the local User model is reloaded, it causes
the User reference to become stale. Only an issue in development, but
still annoying enough to fix.
|
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
diff --git a/builtin/providers/aws/resource_aws_ecs_service.go b/builtin/providers/aws/resource_aws_ecs_service.go
index <HASH>..<HASH> 100644
--- a/builtin/providers/aws/resource_aws_ecs_service.go
+++ b/builtin/providers/aws/resource_aws_ecs_service.go
@@ -404,8 +404,7 @@ func resourceAwsEcsServiceUpdate(d *schema.ResourceData, meta interface{}) error
}
}
// Retry due to AWS IAM policy eventual consistency
// See https://github.com/hashicorp/terraform/issues/4375
err := resource.Retry(2*time.Minute, func() *resource.RetryError {
out, err := conn.UpdateService(&input)
if err != nil {
@@ -414,6 +413,10 @@ func resourceAwsEcsServiceUpdate(d *schema.ResourceData, meta interface{}) error
log.Printf("[DEBUG] Trying to update ECS service again: %#v", err)
return resource.RetryableError(err)
}
+ if ok && awsErr.Code() == "ServiceNotFoundException" {
+ log.Printf("[DEBUG] Trying to update ECS service again: %#v", err)
+ return resource.RetryableError(err)
+ }
return resource.NonRetryableError(err)
}
|
@@ -404,8 +404,7 @@ func resourceAwsEcsServiceUpdate(d *schema.ResourceData, meta interface{}) error
}
}
- // Retry due to AWS IAM policy eventual consistency
- // See https://github.com/hashicorp/terraform/issues/4375
+ // Retry due to IAM & ECS eventual consistency
err := resource.Retry(2*time.Minute, func() *resource.RetryError {
out, err := conn.UpdateService(&input)
provider/aws: Retry ECS svc update on ServiceNotFoundException (#<I>)
|